﻿using System;
using System.Collections.Generic;
using System.Threading.Tasks;
using Microsoft.AspNetCore.SignalR;
using VCinemaApi.Models;
using VCinemaApi.Repositories;

namespace VCinemaApi.Hubs
{
    public class VCinemaHub : Hub<IVCinemaHub>
    {
        private readonly IScreenRepository _screenRepository;
        private readonly IWatcherRepository _watcherRepository;

        public VCinemaHub(IScreenRepository screenRepository, IWatcherRepository watcherRepository)
        {
            _screenRepository = screenRepository;
            _watcherRepository = watcherRepository;
        }

        public override async Task OnConnectedAsync()
        {
            _watcherRepository.AddWatcher(Context.ConnectionId);
            await base.OnConnectedAsync();
        }

        public override async Task OnDisconnectedAsync(Exception exception)
        {
            _watcherRepository.DeleteWatcherByConnectionId(Context.ConnectionId);
            await base.OnDisconnectedAsync(exception);
        }

        public Screen CreateScreen(string name, string source)
        {
            return _screenRepository.AddScreen(name, source);
        }

        public void DeleteScreen(int screenId)
        {
            _screenRepository.DeleteScreenById(screenId);
        }

        public Screen WatchScreen(int screenId)
        {
            var watcher = _watcherRepository.SetWatcherScreenByConnectionId(Context.ConnectionId, screenId);
            return watcher.Screen;
        }

        public void LeaveScreen()
        {
            _watcherRepository.UnsetWatcherScreenByConnectionId(Context.ConnectionId);
        }

        public Watcher SetWatcherName(string name)
        {
            return _watcherRepository.SetWatcherNameByConnectionId(Context.ConnectionId, name);
        }

        public Screen SetPlayState(bool playing)
        {
            throw new NotImplementedException();
        }

        public Screen SetPlayState(bool playing, int playOffset)
        {
            throw new NotImplementedException();
        }
    }
}
