﻿using System.Collections.Generic;
using System.Linq;
using VCinemaApi.Models;

namespace VCinemaApi.Repositories
{
    public class WatcherRepository : IWatcherRepository
    {
        private readonly VCinemaContext _context;

        public WatcherRepository(VCinemaContext context)
        {
            _context = context;
        }

        public IEnumerable<Watcher> GetWatchersByScreenId(int screenId)
        {
            return _context.Watchers.Where(watcher => watcher.Screen.ScreenId == screenId);
        }

        public Watcher GetWatcherByConnectionId(string connectionId)
        {
            return _context.Watchers.SingleOrDefault(watcher => watcher.ConnectionId == connectionId);
        }

        public Watcher AddWatcher(string connectionId)
        {
            var watcher = new Watcher()
            {
                ConnectionId = connectionId,
            };

            _context.Watchers.Add(watcher);
            _context.SaveChanges();

            return watcher;
        }

        public Watcher SetWatcherNameByConnectionId(string connectionId, string name)
        {
            var watcher = GetWatcherByConnectionId(connectionId);

            watcher.Name = name;
            _context.SaveChanges();

            return watcher;
        }

        public Watcher SetWatcherScreenByConnectionId(string connectionId, int screenId)
        {
            var watcher = GetWatcherByConnectionId(connectionId);
            var screen = _context.Screens.Find(screenId);

            watcher.Screen = screen;
            _context.SaveChanges();

            return watcher;
        }

        public Watcher UnsetWatcherScreenByConnectionId(string connectionId)
        {
            var watcher = GetWatcherByConnectionId(connectionId);

            watcher.Screen = null;
            _context.SaveChanges();

            return watcher;
        }

        public void DeleteWatcherByConnectionId(string connectionId)
        {
            var watcher = GetWatcherByConnectionId(connectionId);
            _context.Watchers.Remove(watcher);
            _context.SaveChanges();
        }
    }
}
